agentle.agents.templates.data\_collection.collected\_data
=========================================================

.. automodule:: agentle.agents.templates.data_collection.collected_data

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      CollectedData
      ConfigDict
      MutableMapping
      MutableSequence
   